import type React from "react";
import { Button } from "@fchh/fcos-suite-ui";
import Icon from "@components/Icon";
import type { IconPackageName } from "@config/index";
import type { IconSize } from "@config/index";

interface BaseProps {
  text?: string;
  href: string;
  newTab?: boolean;
  type: "primary" | "secondary" | "tertiary";
  size?: "xs" | "sm" | "md" | "lg" | "xl";
  className?: string;
}

type IconOrWithoutIcon =
  | {
      icon?: never;
      iconPackage?: never;
      iconRight?: never;
      iconSize?: never;
    }
  | {
      icon: string;
      iconPackage?: IconPackageName;
      iconRight?: boolean;
      iconSize?: IconSize;
    };

type CircularOrRounded =
  | {
      circular?: true;
      icon?: string;
      iconPackage?: IconPackageName;
      rounded?: never;
      text?: never;
    }
  | {
      circular?: never;
      icon?: string;
      iconPackage?: IconPackageName;
      rounded?: true;
      text?: string;
    };

type Props = BaseProps & IconOrWithoutIcon & CircularOrRounded;

const ButtonWrapper: React.FC<Props> = ({
  iconPackage = "Carbon",
  icon,
  iconSize,
  ...restProps
}) => {
  return icon ? (
    <Button
      className="fc-my-8"
      {...restProps}
      icon={<Icon pkg={iconPackage} name={icon} size={iconSize} />}
    />
  ) : (
    <Button className="fc-my-8" {...restProps} />
  );
};

export default ButtonWrapper;
