import type React from "react";
import type { CSSProperties } from "react";
import NewsletterForm from "@components/NewsletterForm";

interface Props {
  locale: "de" | "en";
  title: string;
  placeholder: string;
  buttonText: string;
  backgroundColor?: string;
  baseUrl?: string;
}
const NewsletterFullWidth: React.FC<Props> = ({
  backgroundColor = "#EFEAE4",
  locale,
  title,
  placeholder,
  buttonText,
  baseUrl,
}) => {
  const inlineStyles: CSSProperties = {
    backgroundColor,
  };
  return (
    <section style={inlineStyles} className="fc-py-16 lg:fc-pb-20 lg:fc-pt-18">
      <div className="fc-container fc-flex fc-items-center fc-justify-center">
        <div className="fc-w-full fc-grid fc-grid-cols-1 lg:fc-grid-cols-[18%_64%_18%]">
          <NewsletterForm
            locale={locale}
            title={title}
            placeholder={placeholder}
            buttonText={buttonText}
            privacyText={
              <>
                Für den Newsletter-Versand gelten unsere{" "}
                <a
                  className="fc-underline"
                  href={`${baseUrl || ""}/de/privacy`}
                >
                  Datenschutzbestimmungen
                </a>
                .
              </>
            }
            id="newsletter-hero"
            className="lg:fc-col-start-2"
          />
        </div>
      </div>
    </section>
  );
};

export default NewsletterFullWidth;
